#
# SelectionBox
#

xmSelectionBox .sb managed \
    -selectionLabelString "Enter text" \
    -listItems "{item 1} {item 2} {item 3}" \
    -listItemCount 3
